@@ -1171,6 +1171,7 @@ u1_music_store_init (U1MusicStore *music_store)
 	const gchar *url_to_use;
 	SoupSession *session;
 	GtkWidget *alert_icon;
+	GtkWidget *alignment;
 
         g_type_init();
 
@@ -1243,39 +1244,54 @@ u1_music_store_init (U1MusicStore *music_store)
 	gtk_container_add (GTK_CONTAINER (music_store->priv->scroll), music_store->priv->web_viewer);
 
 	/* Create the alert bar */
-	music_store->priv->alertbar = gtk_hbox_new (FALSE, 12);
+	music_store->priv->alertbar = gtk_hbox_new (FALSE, 0);
+	alignment = gtk_vbox_new (FALSE, 0);
 	alert_icon = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING,
 					       GTK_ICON_SIZE_MENU);
-	gtk_box_pack_start (GTK_BOX (music_store->priv->alertbar), alert_icon,
-			    FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (alignment), alert_icon, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (music_store->priv->alertbar), alignment,
+			    FALSE, FALSE, 6);
 	gtk_widget_show (alert_icon);
+	gtk_widget_show (alignment);
 
 	music_store->priv->alert_label = gtk_label_new ("");
 	gtk_misc_set_alignment (GTK_MISC (music_store->priv->alert_label),
 				0.0, 0.5);
+	gtk_label_set_line_wrap (GTK_LABEL (music_store->priv->alert_label),
+				 TRUE);
 	gtk_box_pack_start (GTK_BOX (music_store->priv->alertbar),
 			    music_store->priv->alert_label,
 			    TRUE, TRUE, 0);
 	gtk_widget_show (music_store->priv->alert_label);
 
 	/* Button to install MP3 codec if missing */
+	alignment = gtk_vbox_new (FALSE, 0);
 	music_store->priv->install_btn = gtk_button_new_with_label (_("Install"));
+	gtk_box_pack_start (GTK_BOX (alignment),
+			    music_store->priv->install_btn,
+			    FALSE, FALSE, 0);
 	gtk_box_pack_end (GTK_BOX (music_store->priv->alertbar),
-			  music_store->priv->install_btn,
+			  alignment,
 			  FALSE, FALSE, 6);
 	g_signal_connect (G_OBJECT (music_store->priv->install_btn), "clicked",
 			  G_CALLBACK (_install_missing_codec), music_store);
+	gtk_widget_show (alignment);
 
 	/* Check that MP3 codec is available */
 	g_timeout_add_seconds (3, (GSourceFunc) check_mp3_support, music_store);
 
 	/* Button to subscribe the Purchased Music folder */
+	alignment = gtk_vbox_new (FALSE, 0);
 	music_store->priv->subscribe_btn = gtk_button_new_with_label (_("Subscribe"));
+	gtk_box_pack_start (GTK_BOX (alignment),
+			    music_store->priv->subscribe_btn,
+			    FALSE, FALSE, 0);
 	gtk_box_pack_end (GTK_BOX (music_store->priv->alertbar),
-			  music_store->priv->subscribe_btn,
+			  alignment,
 			  FALSE, FALSE, 6);
 	g_signal_connect (G_OBJECT (music_store->priv->subscribe_btn), "clicked",
 			  G_CALLBACK (subscribe_purchased_folder), music_store);
+	gtk_widget_show (alignment);
 
 	gtk_box_pack_start (GTK_BOX (music_store), music_store->priv->alertbar, FALSE, FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (music_store), music_store->priv->scroll, TRUE, TRUE, 0);
